#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_member import SFMMember
from pycatia.in_interfaces.reference import Reference


class SFMMemberPlane2Curves(SFMMember):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         CATStrFunctionalInterfaces.SfmProfile
                |                            CATStrFunctionalInterfaces.SfmMember
                |                                 SfmMemberPlane2Curves
                | 
                | Interface to manage a Member created with two curves and a
                | plane.
                | Role: To manage member created with two curves and a plane.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_member_plane2_curves = com_object

    @property
    def first_curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FirstCurve() As Reference
                | 
                |     Returns or sets the first and second curve.
                | 
                |     Example:
                |         This example retrieves in Curve the first curve for the
                |         SfmMemberPlane2Curves feature.
                | 
                |          Dim Curve As Reference
                |          Set Curve = SfmMemberPlane2Curves.FirstCurve

        :rtype: Reference
        """

        return Reference(self.sfm_member_plane2_curves.FirstCurve)

    @first_curve.setter
    def first_curve(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_plane2_curves.FirstCurve = value.com_object

    @property
    def first_member(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FirstMember(Reference iFirstMember)
                | 
                |     Returns or sets the first Member.
                | 
                |     Example:
                |         This example retrieves in Member the first Member for the
                |         SfmMemberPlane2Curves feature.
                | 
                |          Dim Member1 As Reference
                |          Set Member1 = SfmMemberPlane2Curves.FirstMember

        :rtype: False
        """

        return self.sfm_member_plane2_curves.FirstMember

    @first_member.setter
    def first_member(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_plane2_curves.FirstMember = value.com_object

    @property
    def plane(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Plane() As Reference
                | 
                |     Returns or sets the intersecting plane.
                | 
                |     Example:
                |         This example retrieves in Plane the intersecting plane for the
                |         SfmMemberPlane2Curves feature.
                | 
                |          Dim Plane As Reference
                |          Set Plane = SfmMemberPlane2Curves.Plane

        :rtype: Reference
        """

        return Reference(self.sfm_member_plane2_curves.Plane)

    @plane.setter
    def plane(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_plane2_curves.Plane = value.com_object

    @property
    def second_curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SecondCurve() As Reference

        :rtype: Reference
        """

        return Reference(self.sfm_member_plane2_curves.SecondCurve)

    @second_curve.setter
    def second_curve(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_plane2_curves.SecondCurve = value.com_object

    @property
    def second_member(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SecondMember(Reference iSecondMember)
                | 
                |     Returns or sets the Second Member.
                | 
                |     Example:
                |         This example retrieves in Member the Second Member for the
                |         SfmMemberPlane2Curves feature.
                | 
                |          Dim Member2 As Reference
                |          Set Member2 = SfmMemberPlane2Curves.SecondMember

        :rtype: False
        """

        return self.sfm_member_plane2_curves.SecondMember

    @second_member.setter
    def second_member(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_plane2_curves.SecondMember = value.com_object

    def __repr__(self):
        return f'SFMMemberPlane2Curves(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_manikin import SWKManikin
from pycatia.dnb_human_modeling_interfaces.swkik_constraint import SWKIKConstraint
from pycatia.system_interfaces.any_object import AnyObject


class SWKIKManager(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SWKIKManager
                | 
                | This interface represents the IK manager of the manikin.
                | The methods on this interface allow to move the manikin in inverse
                | kinematics.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swkik_manager = com_object

    @property
    def behavior(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Behavior() As CATBSTR
                | 
                |     Returns or sets the IK behaviors for this manikin. The string in this
                |     property is the concatenation of the current IK behaviors, like
                |     "Thoracic/Lumbar/Balance".

        :rtype: str
        """

        return self.swkik_manager.Behavior

    @behavior.setter
    def behavior(self, value: str):
        """
        :param str value:
        """

        self.swkik_manager.Behavior = value

    @property
    def manikin(self) -> SWKManikin:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Manikin() As SWKManikin (Read Only)
                | 
                |     Returns the manikin which owns this IK manager.

        :rtype: SWKManikin
        """

        return SWKManikin(self.swkik_manager.Manikin)

    @property
    def number_of_constraints(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfConstraints() As long (Read Only)
                | 
                |     Returns the total number of constraints on the manikin.

        :rtype: int
        """

        return self.swkik_manager.NumberOfConstraints

    def add_constraint(self, pi_end_effector: str) -> SWKIKConstraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddConstraint(CATBSTR piEndEffector) As
                | SWKIKConstraint
                | 
                |     Add a constraint with the given end effector.
                | 
                |     Parameters:
                | 
                |         piEndEffector
                |             The short name of the last segment (the end of the chain, i.e. the
                |             end effector). 
                |         poConstraint
                |             The constraint created.

        :param str pi_end_effector:
        :rtype: SWKIKConstraint
        """
        return SWKIKConstraint(self.swkik_manager.AddConstraint(pi_end_effector))

    def add_constraint_from(self, pi_constraint_from: SWKIKConstraint, po_created_constraint: SWKIKConstraint) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddConstraintFrom(SWKIKConstraint piConstraintFrom,
                | SWKIKConstraint poCreatedConstraint)
                | 
                |     Add a new constraint identical to the one given.
                | 
                |     Parameters:
                | 
                |         piConstraintFrom
                |             The constraint to copy. 
                |         poCreatedConstraint
                |             The new constraint

        :param SWKIKConstraint pi_constraint_from:
        :param SWKIKConstraint po_created_constraint:
        :rtype: None
        """
        return self.swkik_manager.AddConstraintFrom(pi_constraint_from.com_object, po_created_constraint.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_constraint_from'
        # # vba_code = """
        # # Public Function add_constraint_from(swkik_manager)
        # #     Dim piConstraintFrom (2)
        # #     swkik_manager.AddConstraintFrom piConstraintFrom
        # #     add_constraint_from = piConstraintFrom
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_constraint(self, pi_index: int) -> SWKIKConstraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConstraint(long piIndex) As SWKIKConstraint
                | 
                |     Returns the constraint at index piIndex. First element is at index 0.

        :param int pi_index:
        :rtype: SWKIKConstraint
        """
        return SWKIKConstraint(self.swkik_manager.GetConstraint(pi_index))

    def remove_all_constraints(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllConstraints()
                | 
                |     Remove all existing constraints on the manikin.

        :rtype: None
        """
        return self.swkik_manager.RemoveAllConstraints()

    def remove_constraint(self, pi_constraint_to_remove: SWKIKConstraint) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveConstraint(SWKIKConstraint piConstraintToRemove)
                | 
                |     Remove the given constraint.
                | 
                |     Parameters:
                | 
                |         piConstraintToRemove
                |             The constraint to remove.

        :param SWKIKConstraint pi_constraint_to_remove:
        :rtype: None
        """
        return self.swkik_manager.RemoveConstraint(pi_constraint_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_constraint'
        # # vba_code = """
        # # Public Function remove_constraint(swkik_manager)
        # #     Dim piConstraintToRemove (2)
        # #     swkik_manager.RemoveConstraint piConstraintToRemove
        # #     remove_constraint = piConstraintToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def resolve(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Resolve()
                | 
                |     Launch the IK solver to minimize the potential functions
                |     of
                |     the constraints (i.e. reach all defined targets).
                |     Will resolve the constraints for this manikin only.

        :rtype: None
        """
        return self.swkik_manager.Resolve()

    def __repr__(self):
        return f'SWKikManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class FreeSpace(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FreeSpace
                | 
                | Interface to access a CATIAFreeSpace
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.free_space = com_object

    @property
    def volume(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Volume() As double (Read Only)
                | 
                |     Returns the volume.

        :rtype: float
        """

        return self.free_space.Volume

    def get_gravity_center(self, o_gravity_center_coordinates_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetGravityCenter(CATSafeArrayVariant
                | oGravityCenterCoordinatesArray)
                | 
                |     Returns the gravity center.

        :param tuple o_gravity_center_coordinates_array:
        :rtype: None
        """
        return self.free_space.GetGravityCenter(o_gravity_center_coordinates_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_gravity_center'
        # # vba_code = """
        # # Public Function get_gravity_center(free_space)
        # #     Dim oGravityCenterCoordinatesArray (2)
        # #     free_space.GetGravityCenter oGravityCenterCoordinatesArray
        # #     get_gravity_center = oGravityCenterCoordinatesArray
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'FreeSpace(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_rsc_interfaces.rendering_environment import RenderingEnvironment
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class RenderingEnvironments(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     RenderingEnvironments
                | 
                | A collection of all the Rendering Environments objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=RenderingEnvironment)
        self.rendering_environments = com_object

    def add(self, i_environment_type: int) -> RenderingEnvironment:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(short iEnvironmentType) As RenderingEnvironment
                | 
                |     Adds a new environment to the environments collection.
                | 
                |     Parameters:
                | 
                |         iEnvironmentType
                |             The type of the environment to create choosen
                |             among:
                | 
                |             1 - For cubical environment
                |             2 - For spherical environment
                |             3 - For cylindrical environment

        :param int i_environment_type:
        :rtype: RenderingEnvironment
        """
        return RenderingEnvironment(self.rendering_environments.Add(i_environment_type))

    def item(self, i_index: cat_variant) -> RenderingEnvironment:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As RenderingEnvironment
                | 
                |     Returns an environment index in the environments
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the environment to retrieve in the collection of
                |             environments. Compared with other collections, you cannot use the name of the
                |             environment as argument. 
                | 
                |     Returns:
                |         The retrieved environment 
                | 
                | Example:
                |     The following example returns in MyEnvironment the sixth environment in a
                |     environment collection.
                | 
                |      Dim MyEnvironment As RenderingEnvironment
                |      Set MyEnvironment = RenderingEnvironments.Item(6)

        :param cat_variant i_index:
        :rtype: RenderingEnvironment
        """
        return RenderingEnvironment(self.rendering_environments.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a environment from the environments collection.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.rendering_environments.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(rendering_environments)
        # #     Dim iIndex (2)
        # #     rendering_environments.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_all(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAll()
                | 
                |     Removes all environments.of the collection

        :rtype: None
        """
        return self.rendering_environments.RemoveAll()

    def __repr__(self):
        return f'RenderingEnvironments(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_profile import SFMProfile
from pycatia.cat_str_functional_interfaces.sfm_welds import SFMWelds
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class SFMStiffener(SFMProfile):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         CATStrFunctionalInterfaces.SfmProfile
                |                             SfmStiffener
                | 
                | Interface to manage the structure frame modeling Stiffener object Role: Allows
                | accessing and setting of Stiffener's data.
                | 
                | See also:
                |     SfmFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_stiffener = com_object

    @property
    def angle_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AngleMode() As long
                | 
                |     Returns or sets the angle mode.
                | 
                |     Example:
                |         This example retrieves in AngleMode the angle mode of the SfmStiffener
                |         feature.
                | 
                |          Dim AngleMode As Integer
                |          Set AngleMode = SfmStiffener.AngleMode

        :rtype: int
        """

        return self.sfm_stiffener.AngleMode

    @angle_mode.setter
    def angle_mode(self, value: int):
        """
        :param int value:
        """

        self.sfm_stiffener.AngleMode = value

    @property
    def section_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionOrientation() As long
                | 
                |     Returns or sets the section orientation.
                | 
                |     Example:
                |         This example retrieves section orientation of the
                |         Stiffener.
                | 
                |          Dim Orient As Long
                |          Orient = SfmStiffener.SectionOrientation

        :rtype: int
        """

        return self.sfm_stiffener.SectionOrientation

    @section_orientation.setter
    def section_orientation(self, value: int):
        """
        :param int value:
        """

        self.sfm_stiffener.SectionOrientation = value

    @property
    def side_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SideOrientation() As long
                | 
                |     Returns or sets the side orientation. iOrientation value can be selected from InvertOrientation = -1, UnknownOrientation = 0, SameOrientation = 1, GlobalOrientation(Xp) = 2, GlobalOrientation(Xm) = 3, GlobalOrientation(Yp) = 4, GlobalOrientation(Ym) = 5, GlobalOrientation(Zp) = 6, GlobalOrientation(Zm) = 7, GlobalOrientation_Inside = 8, [SameOrientation ] GlobalOrientation_Outside = 9, [InvertOrientation ] GlobalOrientation_LInboard = 10 [Toward center line] GlobalOrientation_LOutboard = 11 [Opposite of previous one ] GlobalOrientation_TInboard = 12 [Toward midship ] GlobalOrientation_TOutboard = 13 [Opposite of previous one]
                | 
                |     Example:
                |         This example retrieves side orientation of the
                |         Stiffener.
                | 
                |          Dim Orient As Long
                |          Orient = SfmStiffener.SideOrientation

        :rtype: int
        """

        return self.sfm_stiffener.SideOrientation

    @side_orientation.setter
    def side_orientation(self, value: int):
        """
        :param int value:
        """

        self.sfm_stiffener.SideOrientation = value

    @property
    def web_support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WebSupport() As Reference
                | 
                |     Returns or sets the web support.
                | 
                |     Example:
                |         This example retrieves in WebSupport the web support of the
                |         SfmStiffener feature.
                | 
                |          Dim WebSupport As Reference
                |          Set WebSupport = SfmStiffener.WebSupport

        :rtype: Reference
        """

        return Reference(self.sfm_stiffener.WebSupport)

    @web_support.setter
    def web_support(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_stiffener.WebSupport = value.com_object

    @property
    def web_support_offset(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WebSupportOffset() As double
                | 
                |     Returns or sets the Stiffener's web support offset.
                | 
                |     Example:
                |         This example retrieves in Offset the web support offset of the
                |         SfmStiffener feature.
                | 
                |          Dim Offset As Double
                |          Set Offset = SfmStiffener.WebSupportOffset

        :rtype: float
        """

        return self.sfm_stiffener.WebSupportOffset

    @web_support_offset.setter
    def web_support_offset(self, value: float):
        """
        :param float value:
        """

        self.sfm_stiffener.WebSupportOffset = value

    @property
    def web_support_offset_param(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WebSupportOffsetParam() As Length (Read Only)

        :rtype: Length
        """

        return Length(self.sfm_stiffener.WebSupportOffsetParam)

    def get_molded_surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMoldedSurface() As Reference
                | 
                |     Returns or sets the molded surface.
                | 
                |     Example:
                |         This example retrieves in MoldedSurface the molded surface of the
                |         SfmStiffener feature.
                | 
                |          Dim MoldedSurface As Reference
                |          Set MoldedSurface = SfmStiffener.GetMoldedSurface

        :rtype: Reference
        """
        return Reference(self.sfm_stiffener.GetMoldedSurface())

    def get_welds(self, i_operating_ele: Reference) -> SFMWelds:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWelds(Reference iOperatingEle) As SfmWelds
                | 
                |     Returns the weld features on the Existing Stiffener.
                | 
                |     Example:
                |         This example retrieves the number of weld features on the Existing
                |         Stiffener.
                | 
                |          Dim OperatedStiffenerObject  As SfmStiffenerObject
                |          Dim Welds As SfmWelds
                |          Set Welds = OperatedStiffenerObject.GetWelds(Nothing)

        :param Reference i_operating_ele:
        :rtype: SFMWelds
        """
        return SFMWelds(self.sfm_stiffener.GetWelds(i_operating_ele.com_object))

    def is_angle_mode_valid(self, i_angle_mode: int) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsAngleModeValid(long iAngleMode) As boolean
                | 
                |     Gets the status about the validity of the angle mode regarding the nature
                |     of the web support (curve or surface).
                | 
                |     Example:
                |         This example retrieves in IsAngleModeValid the angle mode of the
                |         SfmStiffener feature.
                | 
                |          Dim IsAngleModeValid As Bool
                |          Set IsAngleModeValid = SfmStiffener.IsAngleModeValid

        :param int i_angle_mode:
        :rtype: bool
        """
        return self.sfm_stiffener.IsAngleModeValid(i_angle_mode)

    def __repr__(self):
        return f'SFMStiffener(name="{self.name}")'



#! /usr/bin/python3.9

import os
from pathlib import Path
import warnings

from pycatia.base_interfaces.base_application import catia_application as catia
from pycatia.exception_handling.exceptions import CATIAApplicationException


class CATIADocHandler:
    """
    A context manager to open or create a CATIA document.

    .. warning::
        The CATIA document will be closed (and not automatically
        saved) upon exit.

    Only file_name __or__ new_document are required as one document is handled at a time.

    :Example - Open a CATPart:

        >>> from pycatia.base_interfaces.context import CATIADocHandler
        >>> catia_part = 'tests//CF_catia_measurable_part.CATPart'
        >>> with CATIADocHandler(catia_part) as handler:
        >>>     # create the documents object.
        >>>     documents = handler.documents
        >>>     # create the document object.
        >>>     document = handler.document
        >>>     # do some stuff
        >>>     # save document!
        >>>     document.save()

    :Example - Create a new CATPart:

        >>> from pycatia.base_interfaces.context import CATIADocHandler
        >>> with CATIADocHandler(new_document='Part') as handler:
        >>>     # create the CATIA() object.
        >>>     catia = handler.catia
        >>>     # create the documents object.
        >>>     documents = handler.documents
        >>>     # create the document object.
        >>>     document = handler.document
        >>>     # save document!
        >>>     document.save()

    :param str or Path file_name: (optional) path filename to file
    :param str new_document: (optional) 'Part', 'Product' or 'Drawing'.
    """

    def __init__(self, file_name=None, new_document=None):
        self.catia = catia()
        self.documents = self.catia.documents
        self.file_name = file_name
        self.new_document = new_document

        if self.file_name and not os.path.isfile(self.file_name):
            raise CATIAApplicationException(f'Could not find file: {file_name}')
        else:
            if self.file_name:
                self.file_name = Path(self.file_name)

    def __enter__(self):
        self.documents = self.catia.documents
        self.document = None

        if self.file_name and self.new_document:
            raise CATIAApplicationException('Only new_document or file_name arguments should be used. Not both.')

        if self.file_name:
            self.document = self.documents.open(self.file_name)
        elif self.new_document:
            self.document = self.documents.add(self.new_document)

        return self

    def __exit__(self, *args):

        if self.document:
            self.document.close()
        else:
            warnings.warn('The document handler could not detect a document to close.')



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class RpmReport(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     RpmReport

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rpm_report = com_object

    def generate_report(self, i_xml_file_name: str, i_report_file_name: str, i_report_type: str, i_out_dtd_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GenerateReport(CATBSTR iXMLFileName,
                | CATBSTR iReportFileName,
                | CATBSTR iReportType,
                | CATBSTR iOutDTDFileName)
                | 
                |     This method generates a report to an output file. The definition of the
                |     report content is specified by an input XML file.
                | 
                |     Parameters:
                | 
                |         iXMLFileName
                |             XML file name for report definition. 
                |         iReportFileName
                |             The file name to output the report to. 
                |         iReportType
                |             The report type. The following list represents acceptable values:
                |             "Web Page (*.htm)" "Text (*.txt)" "Text (Tab delimited) (*.txt)" "CSV (Comma
                |             delimited) (*.csv)" "XML (*.xml)" "Excel Workbook (*.xls)"
                |             
                |         iOutDTD
                |             If iReportType is an XML file, then a .dtd file name is needed.
                |             Else send in a null string.

        :param str i_xml_file_name:
        :param str i_report_file_name:
        :param str i_report_type:
        :param str i_out_dtd_file_name:
        :rtype: None
        """
        return self.rpm_report.GenerateReport(i_xml_file_name, i_report_file_name, i_report_type, i_out_dtd_file_name)

    def __repr__(self):
        return f'RpmReport(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter


class StrParam(Parameter):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.Parameter
                |                         StrParam
                | 
                | Represents the string parameter.
                | The following example shows how to create it:
                | 
                | 	Dim CATDocs As Documents
                |  Set CATDocs = CATIA.Documents
                |  Dim part1 As Document
                |  Set part1   = CATDocs.Add("CATPart")
                |  Dim material As String
                |  Set material = part1.Parameters.CreateString("material", "glass")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_param = com_object

    @property
    def value(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Value() As CATBSTR
                | 
                |     Returns or sets the string parameter value.
                | 
                |     Example:
                |         This example returns in myValue the value of the string parameter
                |         material:
                | 
                |          
                | 
                |          myValue = material.Value

        :rtype: str
        """

        return self.str_param.Value

    @value.setter
    def value(self, value: str):
        """
        :param str value:
        """

        self.str_param.Value = value

    def get_enumerate_values(self, o_safe_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetEnumerateValues(CATSafeArrayVariant oSafeArray)
                | 
                |     Returns an array containing the different values that the real param can
                |     take in the case of multiple values.
                | 
                |     Example:
                | 
                |          Dim enumValues () as Variant
                |          ReDim enumValues (aStrParameter.GetEnumerateValuesSize() -
                |          1)
                |          aStrParameter.GetEnumerateValues(enumValues)
                |          For i = LBound(enumValues) to UBound(enumValues)
                |            ...
                |          Next

        :param tuple o_safe_array:
        :rtype: None
        """
        return self.str_param.GetEnumerateValues(o_safe_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_enumerate_values'
        # # vba_code = """
        # # Public Function get_enumerate_values(str_param)
        # #     Dim oSafeArray (2)
        # #     str_param.GetEnumerateValues oSafeArray
        # #     get_enumerate_values = oSafeArray
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_enumerate_values_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetEnumerateValuesSize() As long
                | 
                |     Returns the number of enumerate values.

        :rtype: int
        """
        return self.str_param.GetEnumerateValuesSize()

    def set_enumerate_values(self, i_safe_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetEnumerateValues(CATSafeArrayVariant iSafeArray)
                | 
                |     Sets an array containing the different values that the StrParam object can
                |     take in the case of multiple values.
                | 
                |     Parameters:
                | 
                |         The
                |             array of enumerated values.

        :param tuple i_safe_array:
        :rtype: None
        """
        return self.str_param.SetEnumerateValues(i_safe_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_enumerate_values'
        # # vba_code = """
        # # Public Function set_enumerate_values(str_param)
        # #     Dim iSafeArray (2)
        # #     str_param.SetEnumerateValues iSafeArray
        # #     set_enumerate_values = iSafeArray
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def suppress_enumerate_values(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SuppressEnumerateValues()
                | 
                |     Resets the status of the object to a single value object.

        :rtype: None
        """
        return self.str_param.SuppressEnumerateValues()

    def __repr__(self):
        return f'StrParam(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class SFMStandardContourParameters(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     SfmStandardContourParameters
                | 
                | Interface to access Contour Parametrs from/to the collection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Parameter)
        self.sfm_standard_contour_parameters = com_object

    def get_role(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRole() As CATBSTR

        :rtype: str
        """
        return self.sfm_standard_contour_parameters.GetRole()

    def item(self, i_index: cat_variant) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Parameter
                | 
                |     Gets a Reference from the collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             [in] Index of the Reference to be retrieved. 
                |         oReference
                |             [out] Reference. 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This example retrieves Contour Parameters. The Values to these
                |             parameters then can be set.
                | 
                |              Dim oListCkeParms As SfmStandardContourParameters
                |              Set oListCkeParms = ObjSfmContourMgr.GetStdOpeningContourParams("Sfm_Rect")
                |              'Display List of Parameters for Selected Contour
                |              Dim NbOfParam As Long
                |              NbOfParam = oListCkeParms.Count
                |              Dim ContourParam As Parameter
                |              Dim ContourParamName As String
                |              For i = 1 To NbOfParam
                |              Set ContourParam = oListCkeParms.Item(i)
                |              ContourParamName = oListCkeParms.Item(i).Name
                |              MsgBox ContourParamName
                |              If ContourParamName = "Sfm_Width" Then
                |                 ContourParam.ValuateFromString ("1000mm")
                |                 End If
                |               If ContourParamName = "Sfm_Height" Then
                |                 ContourParam.ValuateFromString ("2000mm")
                |                  End If
                |               If ContourParamName = "Sfm_CornerRadius" Then
                |                ContourParam.ValuateFromString ("10mm")
                |                  End If
                |               Next

        :param cat_variant i_index:
        :rtype: Parameter
        """
        return Parameter(self.sfm_standard_contour_parameters.Item(i_index))

    def __repr__(self):
        return f'SFMStandardContourParameters(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr_cntr import SchGRRCntr
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.system_interfaces.any_object import AnyObject


class SchCntrConnect(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCntrConnect
                | 
                | Manage the a schematic connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_cntr_connect = com_object

    def get_transform_matrix(self, i_grr_cntr: SchGRRCntr, o_db6_matrix: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTransformMatrix(SchGRRCntr iGRRCntr,
                | SchListOfDoubles oDb6Matrix)
                | 
                |     Get the transformation matrix needed to transform 'this' connector to be
                |     coincident and aligned with the 'connect to' connector. NOTE: "alignment" in
                |     this context means that the connectors' alignment vectors are facing opposite
                |     directions.
                | 
                |     Parameters:
                | 
                |         iGRRCntr
                |             Pointer to the image of the 'connect to' connector.
                |             
                |         oDb6Matrix
                |             Transformation matrix. for explanation of this argument.
                |             
                |     Example:
                |
                |          Dim objThisIntf As SchCntrConnect
                |          Dim objArg1 As SchGRRCntr
                |          Dim objArg2 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetTransformMatrixobjArg1,objArg2

        :param SchGRRCntr i_grr_cntr:
        :param SchListOfDoubles o_db6_matrix:
        :rtype: None
        """
        return self.sch_cntr_connect.GetTransformMatrix(i_grr_cntr.com_object, o_db6_matrix.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_transform_matrix'
        # # vba_code = """
        # # Public Function get_transform_matrix(sch_cntr_connect)
        # #     Dim iGRRCntr (2)
        # #     sch_cntr_connect.GetTransformMatrix iGRRCntr
        # #     get_transform_matrix = iGRRCntr
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_connect(self, i_grr_cntr: SchGRRCntr, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToConnect(SchGRRCntr iGRRCntr,
                | boolean oBYes)
                | 
                |     Query whether 'this' connector can be connected to the specified connector,
                |     that is, whether their positions are coincident.
                | 
                |     Parameters:
                | 
                |         iGRRCntr
                |             Pointer to the image of the 'connect to' connector.
                |             
                |         oBYes
                |             If TRUE, then it is OK to connect. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCntrConnect
                |          Dim objArg1 As SchGRRCntr
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToConnectobjArg1,bVar2

        :param SchGRRCntr i_grr_cntr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_cntr_connect.OKToConnect(i_grr_cntr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_connect'
        # # vba_code = """
        # # Public Function ok_to_connect(sch_cntr_connect)
        # #     Dim iGRRCntr (2)
        # #     sch_cntr_connect.OKToConnect iGRRCntr
        # #     ok_to_connect = iGRRCntr
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchCntrConnect(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController
from pycatia.system_interfaces.system_service import SystemService


class MeasureSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         MeasureSettingAtt
                | 
                | The interface to access a CATIAMeasureSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.measure_setting_att = com_object

    @property
    def box_display(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BoxDisplay() As boolean
                | 
                |     Returns or sets the BoxDisplay parameter .
                | 
                |     Measure label background is filled if BoxDisplay is True ; there are only
                |     borders if BoxDisplay is False.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: bool
        """

        return self.measure_setting_att.BoxDisplay

    @box_display.setter
    def box_display(self, value: bool):
        """
        :param bool value:
        """

        self.measure_setting_att.BoxDisplay = value

    @property
    def line_width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LineWidth() As short
                | 
                |     Returns or sets the LineWidth parameter.
                | 
                |     The line width index, which ranges from 1 to 63.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.measure_setting_att.LineWidth

    @line_width.setter
    def line_width(self, value: int):
        """
        :param int value:
        """

        self.measure_setting_att.LineWidth = value

    @property
    def part_update_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PartUpdateStatus() As boolean
                | 
                |     Returns or sets the PartUpdateStatus parameter .
                | 
                |     Part is automatically updated if PartUpdateStatus is true.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: bool
        """

        return self.measure_setting_att.PartUpdateStatus

    @part_update_status.setter
    def part_update_status(self, value: bool):
        """
        :param bool value:
        """

        self.measure_setting_att.PartUpdateStatus = value

    @property
    def product_update_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProductUpdateStatus() As boolean
                | 
                |     Returns or sets the ProductUpdateStatus parameter .
                | 
                |     Product is automatically updated if PartUpdateStatus is
                |     true.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: bool
        """

        return self.measure_setting_att.ProductUpdateStatus

    @product_update_status.setter
    def product_update_status(self, value: bool):
        """
        :param bool value:
        """

        self.measure_setting_att.ProductUpdateStatus = value

    @property
    def tilde_display(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TildeDisplay() As boolean
                | 
                |     Returns or sets the TildeDisplay parameter.
                | 
                |     If TildeDisplay is TRUE, a tilde displayed for approximate
                |     measurement.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: bool
        """

        return self.measure_setting_att.TildeDisplay

    @tilde_display.setter
    def tilde_display(self, value: bool):
        """
        :param bool value:
        """

        self.measure_setting_att.TildeDisplay = value

    def get_box_display_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetBoxDisplayInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the BoxDisplay
                |     parameter.
                |     Role:Retrieves the state of the BoxDisplay parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.measure_setting_att.GetBoxDisplayInfo(io_admin_level, io_locked)

    def get_label_color(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetLabelColor(long oR,
                | long oG,
                | long oB)
                | 
                |     Returns the LabelColor parameter.
                | 
                |     Parameters:
                | 
                |         oR
                |             the red component of the color. 
                |         oG
                |             the green component of the color. 
                |         oB
                |             the blue component of the color.
                | 
                |             Ensure consistency with the C++ interface to which the work is
                |             delegated.

        :rtype: tuple
        """
        return self.measure_setting_att.GetLabelColor()

    def get_label_color_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLabelColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LabelColor
                |     parameter.
                |     Role:Retrieves the state of the LabelColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.measure_setting_att.GetLabelColorInfo(io_admin_level, io_locked)

    def get_line_width_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLineWidthInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LineWidth
                |     parameter.
                |     Role:Retrieves the state of the LineWidth parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.measure_setting_att.GetLineWidthInfo(io_admin_level, io_locked)

    def get_part_update_status_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPartUpdateStatusInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PartUpdateStatus
                |     parameter.
                |     Role:Retrieves the state of the PartUpdateStatus parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.measure_setting_att.GetPartUpdateStatusInfo(io_admin_level, io_locked)

    def get_product_update_status_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetProductUpdateStatusInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ProductUpdateStatus
                |     parameter.
                |     Role:Retrieves the state of the ProductUpdateStatus parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.measure_setting_att.GetProductUpdateStatusInfo(io_admin_level, io_locked)

    def get_text_color(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetTextColor(long oR,
                | long oG,
                | long oB)
                | 
                |     Returns the TextColor parameter .
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: tuple
        """

        vba_function_name = 'get_text_color'
        vba_code = """
        Public Function get_text_color(measurable)
            Dim oR long
            Dim oG long
            Dim oB long
            inertia.GetTextColor oR oG oB
            get_principal_moments = (oR, oG, oB)
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_text_color_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetTextColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TextColor
                |     parameter.
                |     Role:Retrieves the state of the TextColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.measure_setting_att.GetTextColorInfo(io_admin_level, io_locked)

    def get_tilde_display_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetTildeDisplayInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TildeDisplay
                |     parameter.
                |     Role:Retrieves the state of the TildeDisplay parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.measure_setting_att.GetTildeDisplayInfo(io_admin_level, io_locked)

    def set_box_display_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetBoxDisplayLock(boolean iLocked)
                | 
                |     Locks or unlocks the BoxDisplay parameter.
                |     Role:Locks or unlocks the BoxDisplay parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.measure_setting_att.SetBoxDisplayLock(i_locked)

    def set_label_color(self, i_r: int, i_g: int, i_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLabelColor(long iR,
                | long iG,
                | long iB)
                | 
                |     Sets the LabelColor parameter.
                | 
                |     Parameters:
                | 
                |         oR
                |             the red component of the color. 
                |         oG
                |             the green component of the color. 
                |         oB
                |             the blue component of the color.
                | 
                |             Ensure consistency with the C++ interface to which the work is
                |             delegated.

        :param int i_r:
        :param int i_g:
        :param int i_b:
        :rtype: None
        """
        return self.measure_setting_att.SetLabelColor(i_r, i_g, i_b)

    def set_label_color_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLabelColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the LabelColor parameter.
                |     Role:Locks or unlocks the LabelColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.measure_setting_att.SetLabelColorLock(i_locked)

    def set_line_width_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLineWidthLock(boolean iLocked)
                | 
                |     Locks or unlocks the LineWidth parameter.
                |     Role:Locks or unlocks the LineWidth parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.measure_setting_att.SetLineWidthLock(i_locked)

    def set_part_update_status_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPartUpdateStatusLock(boolean iLocked)
                | 
                |     Locks or unlocks the PartUpdateStatus parameter.
                |     Role:Locks or unlocks the PartUpdateStatus parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.measure_setting_att.SetPartUpdateStatusLock(i_locked)

    def set_product_update_status_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetProductUpdateStatusLock(boolean iLocked)
                | 
                |     Locks or unlocks the ProductUpdateStatus parameter.
                |     Role:Locks or unlocks the Xxx parameter if it is possible in the current
                |     administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.measure_setting_att.SetProductUpdateStatusLock(i_locked)

    def set_text_color(self, i_r: int, i_g: int, i_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTextColor(long iR,
                | long iG,
                | long iB)
                | 
                |     Sets the TextColor parameter .
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :param int i_r:
        :param int i_g:
        :param int i_b:
        :rtype: None
        """
        return self.measure_setting_att.SetTextColor(i_r, i_g, i_b)

    def set_text_color_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTextColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the TextColor parameter.
                |     Role:Locks or unlocks the TextColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.measure_setting_att.SetTextColorLock(i_locked)

    def set_tilde_display_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTildeDisplayLock(boolean iLocked)
                | 
                |     Locks or unlocks the TildeDisplay parameter.
                |     Role:Locks or unlocks the TildeDisplay parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.measure_setting_att.SetTildeDisplayLock(i_locked)

    def __repr__(self):
        return f'MeasureSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_node import ArrangementNode
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ArrangementNodes(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ArrangementNodes
                | 
                | A Collection object for ArrangementNode objects.
                | Use this object to access individual ArrangementNode objects of an
                | ArrangementRun, ArrangementPathway and ArrangementBoundary.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ArrangementNode)
        self.arrangement_nodes = com_object

    def item(self, i_index: cat_variant) -> ArrangementNode:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ArrangementNode
                | 
                |     Returns the specified ArrangementNode item of the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementNode to retrieve from this
                |             collection.
                | 
                |             To retrieve a specific object by number, use the rank of the
                |             ArrangementNode in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To retrieve a specific
                |                 ArrangementNode by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved ArrangementNode object.

        :param cat_variant i_index:
        :rtype: ArrangementNode
        """
        return ArrangementNode(self.arrangement_nodes.Item(i_index))

    def __repr__(self):
        return f'ArrangementNodes(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_machinable_area import ManufacturingMachinableArea
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingSurfaceGeomArea(ManufacturingMachinableArea):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                        ManufacturingInterfaces.ManufacturingMachinableFeature
                |                            ManufacturingInterfaces.ManufacturingMachinableArea
                |                                 ManufacturingSurfaceGeomArea
                | 
                | Represents the Manufacturing Surface NCGeometry.
                | Role: Allows you to associate geometries with a NCGeometry.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_surface_geom_area = com_object

    def remove_all_geometry(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllGeometry()
                | 
                |     Removes all the geometry linked to a Manufacturing Surface NCGeometry
                |     feature.
                | 
                | 
                |     Example: The following example removes the geometry of the manufacturing
                |     surface NCGeometry feature CurrentNCGeomArea
                | 
                |      Call CurrentNCGeomArea.RemoveAllGeometry()

        :rtype: None
        """
        return self.manufacturing_surface_geom_area.RemoveAllGeometry()

    def set_geometry(self, i_reference: AnyObject, i_product: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGeometry(AnyObject iReference,
                | AnyObject iProduct)
                | 
                |     Sets a geometry of a Manufacturing Surface NCGeometry
                |     feature.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The geometry to be set. 
                |         iProduct
                |             The product containing the geometry to be set. 
                |
                |         Example: The following example sets a geometry Geometry1 to the
                |         manufacturing surface NCGeometry feature
                |         CurrentNCGeomArea
                | 
                |          Call
                |          CurrentNCGeomArea.SetGeometry(Geometry1,PartMachined)

        :param AnyObject i_reference:
        :param AnyObject i_product:
        :rtype: None
        """
        return self.manufacturing_surface_geom_area.SetGeometry(i_reference.com_object, i_product.com_object)

    def __repr__(self):
        return f'ManufacturingSurfaceGeomArea(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.surface_based_shape import SurfaceBasedShape


class SewSurface(SurfaceBasedShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SurfaceBasedShape
                |                             SewSurface
                | 
                | Represents the sewing operation.
                | It sews a shape using a sewing element, such as a surface or a
                | face
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sew_surface = com_object

    @property
    def deviation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Deviation() As double
                | 
                |     Sets or Gets the maximum deviation allowed for smoothing operation in
                |     sewing command. This value must be set in SI unit (m).
                | 
                |     Example: This example retrieves in DeviationValue the maximum deviation
                |     value for the Sewfeature.
                | 
                |      Dim DeviationValue As double
                |      Set DeviationValue = Sew.MaximumDeviationValue

        :rtype: float
        """

        return self.sew_surface.Deviation

    @deviation.setter
    def deviation(self, value: float):
        """
        :param float value:
        """

        self.sew_surface.Deviation = value

    @property
    def deviation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DeviationMode() As long
                | 
                |     Returns or sets the Deviation mode taken into account during Sew
                |     construction.
                |     Legal values:
                | 
                |     0
                |         Unknown Deviation mode.
                |     1
                |         None Deviation mode. Error thrown if maximum deviation exceeds CATIA
                |         resolution.
                |     2
                |         Automatic Deviation mode. Error thrown if maximum deviation exceeds 100
                |         times CATIA resolution.
                |     3
                |         Manual Deviation mode. Error thrown if maximum deviation exceeds input
                |         user deviation.
                | 
                |     Example:
                |         This example retrieves in oMode the Deviation mode for the Sew
                |         feature.
                | 
                |          Dim oMode
                |          Set oMode = Sew.DeviationMode

        :rtype: int
        """

        return self.sew_surface.DeviationMode

    @deviation_mode.setter
    def deviation_mode(self, value: int):
        """
        :param int value:
        """

        self.sew_surface.DeviationMode = value

    @property
    def sewing_intersection_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SewingIntersectionMode() As
                | CatSewingIntersectionMode
                | 
                |     Returns or sets the sewing mode . The sewing side is the side of the body
                |     kept after the sewing. A positive side refers to the same orientation than the
                |     sewing element normal vector.
                | 
                |     Example:
                |         The following example returns in sptSide the sewing side of the sew
                |         shape mySew, and then sets it to catPositiveSide:
                | 
                |          Set sptSide = mySew.SewingSide
                |          mySew.SewingSide = catPositiveSide

        :return: enum cat_sewing_intersection_mode
        :rtype: int
        """

        return self.sew_surface.SewingIntersectionMode

    @sewing_intersection_mode.setter
    def sewing_intersection_mode(self, value: int):
        """
        :param int value: enum cat_sewing_intersection_mode
        """

        self.sew_surface.SewingIntersectionMode = value

    @property
    def sewing_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SewingSide() As CatSplitSide
                | 
                |     Returns or sets the sewing side . The sewing side is the side of the body
                |     kept after the sewing. A positive side refers to the same orientation than the
                |     sewing element normal vector.
                | 
                |     Example:
                |         The following example returns in sptSide the sewing side of the sew
                |         shape mySew, and then sets it to catPositiveSide:
                | 
                |          Set sptSide = mySew.SewingSide
                |          mySew.SewingSide = catPositiveSide

        :return: enum cat_split_side
        :rtype: int
        """

        return self.sew_surface.SewingSide

    @sewing_side.setter
    def sewing_side(self, value: int):
        """
        :param int value: enum cat_split_side
        """

        self.sew_surface.SewingSide = value

    def set_surface_support(self, i_support_surface: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSurfaceSupport(Reference iSupportSurface)
                | 
                |     Sets the surface support for surfacic sew surface.
                | 
                |     Parameters:
                | 
                |         iSupportSurface
                |             A Reference object to a surface (see 
                | 
                |         Reference for more information)

        :param Reference i_support_surface:
        :rtype: None
        """
        return self.sew_surface.SetSurfaceSupport(i_support_surface.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_surface_support'
        # # vba_code = """
        # # Public Function set_surface_support(sew_surface)
        # #     Dim iSupportSurface (2)
        # #     sew_surface.SetSurfaceSupport iSupportSurface
        # #     set_surface_support = iSupportSurface
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_volume_support(self, i_volume: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetVolumeSupport(Reference iVolume)
                | 
                |     Sets the volume support for volume sew surface.
                | 
                |     Parameters:
                | 
                |         iVolume
                |             A Reference object to a volume (see 
                | 
                |         Reference for more information)
                | 
                |         Example:
                |             The following example sets the volume support of SewSurface
                |             firstSewSurface to volumeExtrude volume reference
                |             :
                | 
                |              firstSewSurface.SetVolumeSupport volumeExtrudeRef

        :param Reference i_volume:
        :rtype: None
        """
        return self.sew_surface.SetVolumeSupport(i_volume.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_volume_support'
        # # vba_code = """
        # # Public Function set_volume_support(sew_surface)
        # #     Dim iVolume (2)
        # #     sew_surface.SetVolumeSupport iVolume
        # #     set_volume_support = iVolume
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SewSurface(name="{self.name}")'
